Coverage for numpy\version.py: 0%

# Coverage for numpy\version.py : 0%

## 7 statements 0 run 7 missing 0 excluded

Hot-keys on this page

r m x p toggle line displays

j k next/prev highlighted chunk

0 (zero) top of page

1 (one) first highlighted chunk

1 2 3 4 5 6 7 8 9 10 11 12 | # THIS FILE IS GENERATED FROM NUMPY SETUP.PY # # To compare versions robustly, use `numpy.lib.NumpyVersion` short_version = '1.16.4' version = '1.16.4' full_version = '1.16.4' git_revision = 'a306a62e96e631ef859da5d27d7190aea4a1099a' release = True if not release: version = full_version